@@ -11,7 +11,7 @@ OUTPUT:
   "usr2func": [],
   "usr2type": [{
       "usr": 15041163540773201510,
-      "detailed_name": "class Foo",
+      "detailed_name": "class Foo {}",
       "qual_name_offset": 6,
       "short_name": "Foo",
       "spell": "3:7-3:10|3:1-3:13|2|-1",
@@ -21,7 +21,7 @@ OUTPUT:
       "vars": [],
       "alias_of": 0,
       "kind": 5,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "declarations": ["1:7-1:10|1:1-1:10|1|-1", "2:7-2:10|2:1-2:10|1|-1", "4:7-4:10|4:1-4:10|1|-1"],
       "derived": [],
       "instances": [],
