@@ -19,11 +19,11 @@ OUTPUT:
       "spell": "2:7-2:17|2:1-2:20|2|-1",
       "bases": [],
       "funcs": [],
-      "types": [],
+      "types": [11508089533865125841],
       "vars": [],
       "alias_of": 0,
       "kind": 5,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "declarations": [],
       "derived": [],
       "instances": [3398408600781120939],
@@ -44,6 +44,22 @@ OUTPUT:
       "derived": [],
       "instances": [],
       "uses": ["6:19-6:20|4|-1"]
+    }, {
+      "usr": 11508089533865125841,
+      "detailed_name": "T",
+      "qual_name_offset": 0,
+      "short_name": "",
+      "bases": [],
+      "funcs": [],
+      "types": [],
+      "vars": [],
+      "alias_of": 0,
+      "kind": 26,
+      "parent_kind": 0,
+      "declarations": ["1:19-1:20|1:10-1:20|1025|-1"],
+      "derived": [],
+      "instances": [],
+      "uses": []
     }],
   "usr2var": [{
       "usr": 3398408600781120939,
@@ -53,7 +69,7 @@ OUTPUT:
       "spell": "6:22-6:25|6:1-6:25|2|-1",
       "type": 3286534761799572592,
       "kind": 13,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "storage": 2,
       "declarations": [],
       "uses": []
