@@ -22,11 +22,27 @@ OUTPUT:
       "vars": [],
       "alias_of": 10528472276654770367,
       "kind": 252,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "declarations": [],
       "derived": [],
       "instances": [],
       "uses": ["5:13-5:17|4|-1"]
+    }, {
+      "usr": 8734442555193909854,
+      "detailed_name": "T",
+      "qual_name_offset": 0,
+      "short_name": "",
+      "bases": [],
+      "funcs": [],
+      "types": [],
+      "vars": [],
+      "alias_of": 0,
+      "kind": 26,
+      "parent_kind": 0,
+      "declarations": ["1:19-1:20|1:10-1:20|1025|-1"],
+      "derived": [],
+      "instances": [],
+      "uses": []
     }, {
       "usr": 10528472276654770367,
       "detailed_name": "struct Foo",
@@ -34,10 +50,10 @@ OUTPUT:
       "short_name": "Foo",
       "bases": [],
       "funcs": [],
-      "types": [],
+      "types": [8734442555193909854],
       "vars": [],
       "alias_of": 0,
-      "kind": 5,
+      "kind": 23,
       "parent_kind": 0,
       "declarations": ["2:8-2:11|2:1-2:11|1|-1"],
       "derived": [],
@@ -55,7 +71,7 @@ OUTPUT:
       "vars": [],
       "alias_of": 10528472276654770367,
       "kind": 252,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "declarations": [],
       "derived": [],
       "instances": [],
