@@ -22,7 +22,7 @@ OUTPUT:
       "vars": [],
       "callees": [],
       "kind": 12,
-      "parent_kind": 0,
+      "parent_kind": 1,
       "storage": 0,
       "declarations": [],
       "derived": [],
@@ -35,12 +35,8 @@ OUTPUT:
       "spell": "3:6-3:12|3:1-8:2|2|-1",
       "bases": [],
       "vars": [9121974011454213596],
-      "callees": ["4:13-4:19|468307235068920063|3|132", "4:13-4:19|468307235068920063|3|132", "7:3-7:9|468307235068920063|3|16420"],
-      "kind": 12,
-      "parent_kind": 0,
-      "storage": 0,
-      "declarations": [],
-      "derived": [],
+      "callees": ["4:13-4:19|468307235068920063|3|132", "4:13-4:19|468307235068920063|3|132",
+"7:3-7:9|468307235068920063|3|16420"], "kind": 12, "parent_kind": 1, "storage": 0, "declarations": [], "derived": [],
       "uses": []
     }],
   "usr2type": [],
