@@ -12,24 +12,19 @@ namespace ccls {
 using namespace clang;
 
 namespace {
-llvm::Expected<tooling::Replacements> formatCode(StringRef code, StringRef file,
-                                                 tooling::Range range) {
+llvm::Expected<tooling::Replacements> formatCode(StringRef code, StringRef file, tooling::Range range) {
   auto style = format::getStyle("file", file, "LLVM", code, nullptr);
   if (!style)
     return style.takeError();
-  tooling::Replacements includeReplaces =
-      format::sortIncludes(*style, code, {range}, file);
+  tooling::Replacements includeReplaces = format::sortIncludes(*style, code, {range}, file);
   auto changed = tooling::applyAllReplacements(code, includeReplaces);
   if (!changed)
     return changed.takeError();
-  return includeReplaces.merge(format::reformat(
-      *style, *changed,
-      tooling::calculateRangesAfterReplacements(includeReplaces, {range}),
-      file));
+  return includeReplaces.merge(
+      format::reformat(*style, *changed, tooling::calculateRangesAfterReplacements(includeReplaces, {range}), file));
 }
 
-std::vector<TextEdit> replacementsToEdits(std::string_view code,
-                                          const tooling::Replacements &repls) {
+std::vector<TextEdit> replacementsToEdits(std::string_view code, const tooling::Replacements &repls) {
   std::vector<TextEdit> ret;
   int i = 0, line = 0, col = 0;
   auto move = [&](unsigned p) {
@@ -56,27 +51,23 @@ std::vector<TextEdit> replacementsToEdits(std::string_view code,
 
 void format(ReplyOnce &reply, WorkingFile *wfile, tooling::Range range) {
   std::string_view code = wfile->buffer_content;
-  auto replsOrErr = formatCode(
-      StringRef(code.data(), code.size()),
-      StringRef(wfile->filename.data(), wfile->filename.size()), range);
+  auto replsOrErr =
+      formatCode(StringRef(code.data(), code.size()), StringRef(wfile->filename.data(), wfile->filename.size()), range);
   if (replsOrErr)
     reply(replacementsToEdits(code, *replsOrErr));
   else
-    reply.error(ErrorCode::UnknownErrorCode,
-                llvm::toString(replsOrErr.takeError()));
+    reply.error(ErrorCode::UnknownErrorCode, llvm::toString(replsOrErr.takeError()));
 }
 } // namespace
 
-void MessageHandler::textDocument_formatting(DocumentFormattingParam &param,
-                                             ReplyOnce &reply) {
+void MessageHandler::textDocument_formatting(DocumentFormattingParam &param, ReplyOnce &reply) {
   auto [file, wf] = findOrFail(param.textDocument.uri.getPath(), reply);
   if (!wf)
     return;
   format(reply, wf, {0, (unsigned)wf->buffer_content.size()});
 }
 
-void MessageHandler::textDocument_onTypeFormatting(
-    DocumentOnTypeFormattingParam &param, ReplyOnce &reply) {
+void MessageHandler::textDocument_onTypeFormatting(DocumentOnTypeFormattingParam &param, ReplyOnce &reply) {
   auto [file, wf] = findOrFail(param.textDocument.uri.getPath(), reply);
   if (!wf) {
     return;
@@ -89,15 +80,13 @@ void MessageHandler::textDocument_onTypeFormatting(
   format(reply, wf, {(unsigned)lbrace, unsigned(pos - lbrace)});
 }
 
-void MessageHandler::textDocument_rangeFormatting(
-    DocumentRangeFormattingParam &param, ReplyOnce &reply) {
+void MessageHandler::textDocument_rangeFormatting(DocumentRangeFormattingParam &param, ReplyOnce &reply) {
   auto [file, wf] = findOrFail(param.textDocument.uri.getPath(), reply);
   if (!wf) {
     return;
   }
   std::string_view code = wf->buffer_content;
-  int begin = getOffsetForPosition(param.range.start, code),
-      end = getOffsetForPosition(param.range.end, code);
+  int begin = getOffsetForPosition(param.range.start, code), end = getOffsetForPosition(param.range.end, code);
   format(reply, wf, {(unsigned)begin, unsigned(end - begin)});
 }
 } // namespace ccls
