@@ -108,14 +108,12 @@ struct InMemoryIndexFile {
 std::shared_mutex g_index_mutex;
 std::unordered_map<std::string, InMemoryIndexFile> g_index;
 
-bool cacheInvalid(VFS *vfs, IndexFile *prev, const std::string &path,
-                  const std::vector<const char *> &args,
+bool cacheInvalid(VFS *vfs, IndexFile *prev, const std::string &path, const std::vector<const char *> &args,
                   const std::optional<std::string> &from) {
   {
     std::lock_guard<std::mutex> lock(vfs->mutex);
     if (prev->mtime < vfs->state[path].timestamp) {
-      LOG_V(1) << "timestamp changed for " << path
-               << (from ? " (via " + *from + ")" : std::string());
+      LOG_V(1) << "timestamp changed for " << path << (from ? " (via " + *from + ")" : std::string());
       return true;
     }
   }
@@ -131,9 +129,8 @@ bool cacheInvalid(VFS *vfs, IndexFile *prev, const std::string &path,
   if (changed < 0 && prev->args.size() != args.size())
     changed = size;
   if (changed >= 0)
-    LOG_V(1) << "args changed for " << path
-             << (from ? " (via " + *from + ")" : std::string()) << "; old: "
-             << (changed < prev->args.size() ? prev->args[changed] : "")
+    LOG_V(1) << "args changed for " << path << (from ? " (via " + *from + ")" : std::string())
+             << "; old: " << (changed < prev->args.size() ? prev->args[changed] : "")
              << "; new: " << (changed < size ? args[changed] : "");
   return changed >= 0;
 };
@@ -158,14 +155,12 @@ std::string getCachePath(std::string src) {
   for (auto &[root, _] : g_config->workspaceFolders)
     if (StringRef(src).startswith(root)) {
       auto len = root.size();
-      return g_config->cache.directory +
-             escapeFileName(root.substr(0, len - 1)) + '/' +
+      return g_config->cache.directory + escapeFileName(root.substr(0, len - 1)) + '/' +
              escapeFileName(src.substr(len));
     }
   return g_config->cache.directory + '@' +
-         escapeFileName(g_config->fallbackFolder.substr(
-             0, g_config->fallbackFolder.size() - 1)) +
-         '/' + escapeFileName(src);
+         escapeFileName(g_config->fallbackFolder.substr(0, g_config->fallbackFolder.size() - 1)) + '/' +
+         escapeFileName(src);
 }
 
 std::unique_ptr<IndexFile> rawCacheLoad(const std::string &path) {
@@ -180,13 +175,11 @@ std::unique_ptr<IndexFile> rawCacheLoad(const std::string &path) {
 
   std::string cache_path = getCachePath(path);
   std::optional<std::string> file_content = readContent(cache_path);
-  std::optional<std::string> serialized_indexed_content =
-      readContent(appendSerializationFormat(cache_path));
+  std::optional<std::string> serialized_indexed_content = readContent(appendSerializationFormat(cache_path));
   if (!file_content || !serialized_indexed_content)
     return nullptr;
 
-  return ccls::deserialize(g_config->cache.format, path,
-                           *serialized_indexed_content, *file_content,
+  return ccls::deserialize(g_config->cache.format, path, *serialized_indexed_content, *file_content,
                            IndexFile::kMajorVersion);
 }
 
@@ -196,8 +189,8 @@ std::mutex &getFileMutex(const std::string &path) {
   return mutexes[std::hash<std::string>()(path) % n_MUTEXES];
 }
 
-bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
-                   Project *project, VFS *vfs, const GroupMatch &matcher) {
+bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles, Project *project, VFS *vfs,
+                   const GroupMatch &matcher) {
   std::optional<IndexRequest> opt_request = index_request->tryPopFront();
   if (!opt_request)
     return false;
@@ -220,8 +213,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
     return false;
   }
 
-  Project::Entry entry =
-      project->findEntry(request.path, true, request.must_exist);
+  Project::Entry entry = project->findEntry(request.path, true, request.must_exist);
   if (request.must_exist && entry.filename.empty())
     return true;
   if (request.args.size())
@@ -230,8 +222,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
   std::unique_ptr<IndexFile> prev;
 
   bool deleted = request.mode == IndexMode::Delete,
-       no_linkage = g_config->index.initialNoLinkage ||
-                    request.mode != IndexMode::Background;
+       no_linkage = g_config->index.initialNoLinkage || request.mode != IndexMode::Background;
   int reparse = 0;
   if (deleted)
     reparse = 2;
@@ -259,8 +250,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
     if (request.path != path_to_index)
       vfs->state[request.path].step = 0;
   }
-  bool track = g_config->index.trackDependency > 1 ||
-               (g_config->index.trackDependency == 1 && request.ts < loaded_ts);
+  bool track = g_config->index.trackDependency > 1 || (g_config->index.trackDependency == 1 && request.ts < loaded_ts);
   if (!reparse && !track)
     return true;
 
@@ -269,22 +259,19 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
       std::unique_lock lock(getFileMutex(path_to_index));
       prev = rawCacheLoad(path_to_index);
       if (!prev || prev->no_linkage < no_linkage ||
-          cacheInvalid(vfs, prev.get(), path_to_index, entry.args,
-                       std::nullopt))
+          cacheInvalid(vfs, prev.get(), path_to_index, entry.args, std::nullopt))
         break;
       if (track)
         for (const auto &dep : prev->dependencies) {
           if (auto mtime1 = lastWriteTime(dep.first.val().str())) {
             if (dep.second < *mtime1) {
               reparse = 2;
-              LOG_V(1) << "timestamp changed for " << path_to_index << " via "
-                       << dep.first.val().str();
+              LOG_V(1) << "timestamp changed for " << path_to_index << " via " << dep.first.val().str();
               break;
             }
           } else {
             reparse = 2;
-            LOG_V(1) << "timestamp changed for " << path_to_index << " via "
-                     << dep.first.val().str();
+            LOG_V(1) << "timestamp changed for " << path_to_index << " via " << dep.first.val().str();
             break;
           }
         }
@@ -298,8 +285,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
       LOG_S(INFO) << "load cache for " << path_to_index;
       auto dependencies = prev->dependencies;
       IndexUpdate update = IndexUpdate::createDelta(nullptr, prev.get());
-      on_indexed->pushBack(std::move(update),
-                           request.mode != IndexMode::Background);
+      on_indexed->pushBack(std::move(update), request.mode != IndexMode::Background);
       {
         std::lock_guard lock1(vfs->mutex);
         VFS::State &st = vfs->state[path_to_index];
@@ -328,8 +314,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
             st.step = 3;
         }
         IndexUpdate update = IndexUpdate::createDelta(nullptr, prev.get());
-        on_indexed->pushBack(std::move(update),
-                             request.mode != IndexMode::Background);
+        on_indexed->pushBack(std::move(update), request.mode != IndexMode::Background);
         if (entry.id >= 0) {
           std::lock_guard lock2(project->mtx);
           project->root2folder[entry.root].path2entry_index[path] = entry.id;
@@ -353,9 +338,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
         remapped.emplace_back(path_to_index, content);
     }
     bool ok;
-    auto result =
-        idx::index(completion, wfiles, vfs, entry.directory, path_to_index,
-                   entry.args, remapped, no_linkage, ok);
+    auto result = idx::index(wfiles, vfs, entry.directory, path_to_index, entry.args, remapped, no_linkage, ok);
     indexes = std::move(result.indexes);
     n_errs = result.n_errs;
     first_error = std::move(result.first_error);
@@ -394,8 +377,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
     }
 
     if (!deleted)
-      LOG_IF_S(INFO, loud) << "store index for " << path
-                           << " (delta: " << !!prev << ")";
+      LOG_IF_S(INFO, loud) << "store index for " << path << " (delta: " << !!prev << ")";
     {
       std::lock_guard lock(getFileMutex(path));
       int loaded = vfs->loaded(path), retain = g_config->cache.retainInMemory;
@@ -405,8 +387,7 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
         prev.reset();
       if (retain > 0 && retain <= loaded + 1) {
         std::lock_guard lock(g_index_mutex);
-        auto it = g_index.insert_or_assign(
-            path, InMemoryIndexFile{curr->file_contents, *curr});
+        auto it = g_index.insert_or_assign(path, InMemoryIndexFile{curr->file_contents, *curr});
         std::string().swap(it.first->second.index.file_contents);
       }
       if (g_config->cache.directory.size()) {
@@ -416,16 +397,12 @@ bool indexer_Parse(SemaManager *completion, WorkingFiles *wfiles,
           (void)sys::fs::remove(appendSerializationFormat(cache_path));
         } else {
           if (g_config->cache.hierarchicalPath)
-            sys::fs::create_directories(
-                sys::path::parent_path(cache_path, sys::path::Style::posix),
-                true);
+            sys::fs::create_directories(sys::path::parent_path(cache_path, sys::path::Style::posix), true);
           writeToFile(cache_path, curr->file_contents);
-          writeToFile(appendSerializationFormat(cache_path),
-                      serialize(g_config->cache.format, *curr));
+          writeToFile(appendSerializationFormat(cache_path), serialize(g_config->cache.format, *curr));
         }
       }
-      on_indexed->pushBack(IndexUpdate::createDelta(prev.get(), curr.get()),
-                           request.mode != IndexMode::Background);
+      on_indexed->pushBack(IndexUpdate::createDelta(prev.get(), curr.get()), request.mode != IndexMode::Background);
       {
         std::lock_guard lock1(vfs->mutex);
         vfs->state[path].loaded++;
@@ -446,9 +423,13 @@ void quit(SemaManager &manager) {
   g_quit.store(true, std::memory_order_relaxed);
   manager.quit();
 
-  { std::lock_guard lock(index_request->mutex_); }
+  {
+    std::lock_guard lock(index_request->mutex_);
+  }
   indexer_waiter->cv.notify_all();
-  { std::lock_guard lock(for_stdout->mutex_); }
+  {
+    std::lock_guard lock(for_stdout->mutex_);
+  }
   stdout_waiter->cv.notify_one();
   std::unique_lock lock(thread_mtx);
   no_active_threads.wait(lock, [] { return !active_threads; });
@@ -479,8 +460,7 @@ void init() {
   for_stdout = new ThreadedQueue<std::string>(stdout_waiter);
 }
 
-void indexer_Main(SemaManager *manager, VFS *vfs, Project *project,
-                  WorkingFiles *wfiles) {
+void indexer_Main(SemaManager *manager, VFS *vfs, Project *project, WorkingFiles *wfiles) {
   GroupMatch matcher(g_config->index.whitelist, g_config->index.blacklist);
   while (true)
     if (!indexer_Parse(manager, wfiles, project, vfs, matcher))
@@ -507,8 +487,7 @@ void indexerSort(const std::unordered_map<std::string, int> &dir2prio) {
 
 void main_OnIndexed(DB *db, WorkingFiles *wfiles, IndexUpdate *update) {
   if (update->refresh) {
-    LOG_S(INFO)
-        << "loaded project. Refresh semantic highlight for all working file.";
+    LOG_S(INFO) << "loaded project. Refresh semantic highlight for all working file.";
     std::lock_guard lock(wfiles->mutex);
     for (auto &[f, wf] : wfiles->files) {
       std::string path = lowerPathIfInsensitive(f);
@@ -532,8 +511,7 @@ void main_OnIndexed(DB *db, WorkingFiles *wfiles, IndexUpdate *update) {
     if (WorkingFile *wfile = wfiles->getFile(def_u.first.path)) {
       // FIXME With index.onChange: true, use buffer_content only for
       // request.path
-      wfile->setIndexContent(g_config->index.onChange ? wfile->buffer_content
-                                                      : def_u.second);
+      wfile->setIndexContent(g_config->index.onChange ? wfile->buffer_content : def_u.second);
       QueryFile &file = db->files[update->file_id];
       emitSkippedRanges(wfile, file);
       emitSemanticHighlight(db, wfile, file);
@@ -587,8 +565,7 @@ void launchStdin() {
       assert(!document->HasParseError());
 
       JsonReader reader{document.get()};
-      if (!reader.m->HasMember("jsonrpc") ||
-          std::string((*reader.m)["jsonrpc"].GetString()) != "2.0")
+      if (!reader.m->HasMember("jsonrpc") || std::string((*reader.m)["jsonrpc"].GetString()) != "2.0")
         break;
       RequestId id;
       std::string method;
@@ -604,8 +581,7 @@ void launchStdin() {
       // g_config is not available before "initialize". Use 0 in that case.
       on_request->pushBack(
           {id, std::move(method), std::move(message), std::move(document),
-           chrono::steady_clock::now() +
-               chrono::milliseconds(g_config ? g_config->request.timeout : 0)});
+           chrono::steady_clock::now() + chrono::milliseconds(g_config ? g_config->request.timeout : 0)});
 
       if (received_exit)
         break;
@@ -618,9 +594,8 @@ void launchStdin() {
       std::copy(str.begin(), str.end(), message.get());
       auto document = std::make_unique<rapidjson::Document>();
       document->Parse(message.get(), str.size());
-      on_request->pushBack({RequestId(), std::string("exit"),
-                            std::move(message), std::move(document),
-                            chrono::steady_clock::now()});
+      on_request->pushBack(
+          {RequestId(), std::string("exit"), std::move(message), std::move(document), chrono::steady_clock::now()});
     }
     threadLeave();
   }).detach();
@@ -708,6 +683,14 @@ void mainLoop() {
         path2backlog[ex.path].push_back(&backlog.back());
       }
 
+    // If the "exit" notification has been received, clear all index requests
+    // to make indexers stop in time.
+    if (g_quit.load(std::memory_order_relaxed)) {
+      index_request->apply([&](std::deque<IndexRequest> &q) {
+        q.clear();
+      });
+    }
+
     bool indexed = false;
     for (int i = 20; i--;) {
       std::optional<IndexUpdate> update = on_indexed->tryPopFront();
@@ -750,11 +733,8 @@ void mainLoop() {
         WorkDoneProgressParam param;
         param.token = index_progress_token;
         param.value.kind = "report";
-        param.value.message =
-            (Twine(completed - last_idle) + "/" + Twine(enqueued - last_idle))
-                .str();
-        param.value.percentage =
-            100 * (completed - last_idle) / (enqueued - last_idle);
+        param.value.message = (Twine(completed - last_idle) + "/" + Twine(enqueued - last_idle)).str();
+        param.value.percentage = 100 * (completed - last_idle) / (enqueued - last_idle);
         notify("$/progress", param);
       } else if (in_progress) {
         stats.last_idle.store(enqueued, std::memory_order_relaxed);
@@ -791,9 +771,7 @@ void standalone(const std::string &root) {
   WorkingFiles wfiles;
   VFS vfs;
   SemaManager manager(
-      nullptr, nullptr,
-      [](const std::string &, const std::vector<Diagnostic> &) {},
-      [](const RequestId &id) {});
+      nullptr, nullptr, [](const std::string &, const std::vector<Diagnostic> &) {}, [](const RequestId &id) {});
 
   MessageHandler handler;
   handler.project = &project;
@@ -826,12 +804,11 @@ void standalone(const std::string &root) {
   quit(manager);
 }
 
-void index(const std::string &path, const std::vector<const char *> &args,
-           IndexMode mode, bool must_exist, RequestId id) {
+void index(const std::string &path, const std::vector<const char *> &args, IndexMode mode, bool must_exist,
+           RequestId id) {
   if (!path.empty())
     stats.enqueued++;
-  index_request->pushBack({path, args, mode, must_exist, std::move(id)},
-                          mode != IndexMode::Background);
+  index_request->pushBack({path, args, mode, must_exist, std::move(id)}, mode != IndexMode::Background);
 }
 
 void removeCache(const std::string &path) {
@@ -852,8 +829,7 @@ std::optional<std::string> loadIndexedContent(const std::string &path) {
   return readContent(getCachePath(path));
 }
 
-void notifyOrRequest(const char *method, bool request,
-                     const std::function<void(JsonWriter &)> &fn) {
+void notifyOrRequest(const char *method, bool request, const std::function<void(JsonWriter &)> &fn) {
   rapidjson::StringBuffer output;
   rapidjson::Writer<rapidjson::StringBuffer> w(output);
   w.StartObject();
@@ -869,13 +845,11 @@ void notifyOrRequest(const char *method, bool request,
   JsonWriter writer(&w);
   fn(writer);
   w.EndObject();
-  LOG_V(2) << (request ? "RequestMessage: " : "NotificationMessage: ")
-           << method;
+  LOG_V(2) << (request ? "RequestMessage: " : "NotificationMessage: ") << method;
   for_stdout->pushBack(output.GetString());
 }
 
-static void reply(const RequestId &id, const char *key,
-                  const std::function<void(JsonWriter &)> &fn) {
+static void reply(const RequestId &id, const char *key, const std::function<void(JsonWriter &)> &fn) {
   rapidjson::StringBuffer output;
   rapidjson::Writer<rapidjson::StringBuffer> w(output);
   w.StartObject();
@@ -902,13 +876,8 @@ static void reply(const RequestId &id, const char *key,
   for_stdout->pushBack(output.GetString());
 }
 
-void reply(const RequestId &id, const std::function<void(JsonWriter &)> &fn) {
-  reply(id, "result", fn);
-}
+void reply(const RequestId &id, const std::function<void(JsonWriter &)> &fn) { reply(id, "result", fn); }
 
-void replyError(const RequestId &id,
-                const std::function<void(JsonWriter &)> &fn) {
-  reply(id, "error", fn);
-}
+void replyError(const RequestId &id, const std::function<void(JsonWriter &)> &fn) { reply(id, "error", fn); }
 } // namespace pipeline
 } // namespace ccls
